@@ -224,9 +224,8 @@ class MinimalConfluence:
         return self._post(
             f"content/{confluence_page.id}/child/attachment/{existing_attachment.id}/"
             f"data",
-            json={"comment": message} if message else None,
             headers={"X-Atlassian-Token": "nocheck"},
-            files={"file": fp},
+            files={"file": fp, "comment": message if message else None},
         )
 
     def create_attachment(self, confluence_page, fp, message=""):
@@ -235,7 +234,7 @@ class MinimalConfluence:
             json={"comment": message} if message else None,
             headers={"X-Atlassian-Token": "nocheck"},
             params={"allowDuplicated": "true"},
-            files={"file": fp},
+            files={"file": fp, "comment": message if message else None},
         )
 
     def add_labels(self, page, labels):
